# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .access_point import *
from .api_key import *
from .business_metadata import *
from .business_metadata_binding import *
from .byok_key import *
from .catalog_entity_attributes import *
from .cluster_link import *
from .connector import *
from .custom_connector_plugin import *
from .dns_forwarder import *
from .dns_record import *
from .environment import *
from .flink_compute_pool import *
from .flink_statement import *
from .get_access_point import *
from .get_business_metadata import *
from .get_business_metadata_binding import *
from .get_byok_key import *
from .get_dns_record import *
from .get_environment import *
from .get_environments import *
from .get_flink_compute_pool import *
from .get_flink_region import *
from .get_gateway import *
from .get_group_mapping import *
from .get_identity_pool import *
from .get_identity_provider import *
from .get_invitation import *
from .get_ip_addresses import *
from .get_kafka_client_quota import *
from .get_kafka_cluster import *
from .get_kafka_topic import *
from .get_ksql_cluster import *
from .get_network import *
from .get_network_link_endpoint import *
from .get_network_link_service import *
from .get_organization import *
from .get_peering import *
from .get_private_link_access import *
from .get_private_link_attachment import *
from .get_private_link_attachment_connection import *
from .get_role_binding import *
from .get_schema import *
from .get_schema_registry_cluster import *
from .get_schema_registry_cluster_config import *
from .get_schema_registry_cluster_mode import *
from .get_schema_registry_clusters import *
from .get_schema_registry_dek import *
from .get_schema_registry_kek import *
from .get_schema_registry_region import *
from .get_schemas import *
from .get_service_account import *
from .get_subject_config import *
from .get_subject_mode import *
from .get_tag import *
from .get_tag_binding import *
from .get_transit_gateway_attachment import *
from .get_user import *
from .get_users import *
from .group_mapping import *
from .identity_pool import *
from .identity_provider import *
from .invitation import *
from .kafka_acl import *
from .kafka_client_quota import *
from .kafka_cluster import *
from .kafka_cluster_config import *
from .kafka_mirror_topic import *
from .kafka_topic import *
from .ksql_cluster import *
from .network import *
from .network_link_endpoint import *
from .network_link_service import *
from .peering import *
from .private_link_access import *
from .private_link_attachment import *
from .private_link_attachment_connection import *
from .provider import *
from .role_binding import *
from .schema import *
from .schema_exporter import *
from .schema_registry_cluster import *
from .schema_registry_cluster_config import *
from .schema_registry_cluster_mode import *
from .schema_registry_dek import *
from .schema_registry_kek import *
from .service_account import *
from .subject_config import *
from .subject_mode import *
from .tag import *
from .tag_binding import *
from .tf_importer import *
from .transit_gateway_attachment import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_confluentcloud.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_confluentcloud.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "confluentcloud",
  "mod": "index/accessPoint",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/accessPoint:AccessPoint": "AccessPoint"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/apiKey",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/businessMetadata",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/businessMetadata:BusinessMetadata": "BusinessMetadata"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/businessMetadataBinding",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/businessMetadataBinding:BusinessMetadataBinding": "BusinessMetadataBinding"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/byokKey",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/byokKey:ByokKey": "ByokKey"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/catalogEntityAttributes",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/catalogEntityAttributes:CatalogEntityAttributes": "CatalogEntityAttributes"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/clusterLink",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/clusterLink:ClusterLink": "ClusterLink"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/connector",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/connector:Connector": "Connector"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/customConnectorPlugin",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/customConnectorPlugin:CustomConnectorPlugin": "CustomConnectorPlugin"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/dnsForwarder",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/dnsForwarder:DnsForwarder": "DnsForwarder"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/dnsRecord",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/dnsRecord:DnsRecord": "DnsRecord"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/environment",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/environment:Environment": "Environment"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/flinkComputePool",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/flinkComputePool:FlinkComputePool": "FlinkComputePool"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/flinkStatement",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/flinkStatement:FlinkStatement": "FlinkStatement"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/groupMapping",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/groupMapping:GroupMapping": "GroupMapping"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/identityPool",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/identityPool:IdentityPool": "IdentityPool"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/identityProvider",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/identityProvider:IdentityProvider": "IdentityProvider"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/invitation",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/invitation:Invitation": "Invitation"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaAcl",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaAcl:KafkaAcl": "KafkaAcl"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaClientQuota",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaClientQuota:KafkaClientQuota": "KafkaClientQuota"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaCluster",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaCluster:KafkaCluster": "KafkaCluster"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaClusterConfig",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaClusterConfig:KafkaClusterConfig": "KafkaClusterConfig"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaMirrorTopic",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaMirrorTopic:KafkaMirrorTopic": "KafkaMirrorTopic"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/kafkaTopic",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/kafkaTopic:KafkaTopic": "KafkaTopic"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/ksqlCluster",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/ksqlCluster:KsqlCluster": "KsqlCluster"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/network",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/network:Network": "Network"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/networkLinkEndpoint",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/networkLinkEndpoint:NetworkLinkEndpoint": "NetworkLinkEndpoint"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/networkLinkService",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/networkLinkService:NetworkLinkService": "NetworkLinkService"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/peering",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/peering:Peering": "Peering"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/privateLinkAccess",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/privateLinkAccess:PrivateLinkAccess": "PrivateLinkAccess"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/privateLinkAttachment",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/privateLinkAttachment:PrivateLinkAttachment": "PrivateLinkAttachment"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/privateLinkAttachmentConnection",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/privateLinkAttachmentConnection:PrivateLinkAttachmentConnection": "PrivateLinkAttachmentConnection"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/roleBinding",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/roleBinding:RoleBinding": "RoleBinding"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schema",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaExporter",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaExporter:SchemaExporter": "SchemaExporter"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryCluster",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryCluster:SchemaRegistryCluster": "SchemaRegistryCluster"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryClusterConfig",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryClusterConfig:SchemaRegistryClusterConfig": "SchemaRegistryClusterConfig"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryClusterMode",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryClusterMode:SchemaRegistryClusterMode": "SchemaRegistryClusterMode"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryDek",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryDek:SchemaRegistryDek": "SchemaRegistryDek"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/schemaRegistryKek",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/schemaRegistryKek:SchemaRegistryKek": "SchemaRegistryKek"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/serviceAccount",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/serviceAccount:ServiceAccount": "ServiceAccount"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/subjectConfig",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/subjectConfig:SubjectConfig": "SubjectConfig"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/subjectMode",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/subjectMode:SubjectMode": "SubjectMode"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/tag",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/tag:Tag": "Tag"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/tagBinding",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/tagBinding:TagBinding": "TagBinding"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/tfImporter",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/tfImporter:TfImporter": "TfImporter"
  }
 },
 {
  "pkg": "confluentcloud",
  "mod": "index/transitGatewayAttachment",
  "fqn": "pulumi_confluentcloud",
  "classes": {
   "confluentcloud:index/transitGatewayAttachment:TransitGatewayAttachment": "TransitGatewayAttachment"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "confluentcloud",
  "token": "pulumi:providers:confluentcloud",
  "fqn": "pulumi_confluentcloud",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAccessPointResult',
    'AwaitableGetAccessPointResult',
    'get_access_point',
    'get_access_point_output',
]

@pulumi.output_type
class GetAccessPointResult:
    """
    A collection of values returned by getAccessPoint.
    """
    def __init__(__self__, aws_egress_private_link_endpoints=None, azure_egress_private_link_endpoints=None, display_name=None, environment=None, gateways=None, id=None):
        if aws_egress_private_link_endpoints and not isinstance(aws_egress_private_link_endpoints, list):
            raise TypeError("Expected argument 'aws_egress_private_link_endpoints' to be a list")
        pulumi.set(__self__, "aws_egress_private_link_endpoints", aws_egress_private_link_endpoints)
        if azure_egress_private_link_endpoints and not isinstance(azure_egress_private_link_endpoints, list):
            raise TypeError("Expected argument 'azure_egress_private_link_endpoints' to be a list")
        pulumi.set(__self__, "azure_egress_private_link_endpoints", azure_egress_private_link_endpoints)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if gateways and not isinstance(gateways, list):
            raise TypeError("Expected argument 'gateways' to be a list")
        pulumi.set(__self__, "gateways", gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="awsEgressPrivateLinkEndpoints")
    def aws_egress_private_link_endpoints(self) -> Sequence['outputs.GetAccessPointAwsEgressPrivateLinkEndpointResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "aws_egress_private_link_endpoints")

    @property
    @pulumi.getter(name="azureEgressPrivateLinkEndpoints")
    def azure_egress_private_link_endpoints(self) -> Sequence['outputs.GetAccessPointAzureEgressPrivateLinkEndpointResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "azure_egress_private_link_endpoints")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        (Required String) A human-readable name for the Access Point.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def environment(self) -> 'outputs.GetAccessPointEnvironmentResult':
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter
    def gateways(self) -> Sequence['outputs.GetAccessPointGatewayResult']:
        """
        (Required Configuration Block) supports the following:
        """
        return pulumi.get(self, "gateways")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the gateway to which the Access Point belongs, for example, `gw-abc123`.
        """
        return pulumi.get(self, "id")


class AwaitableGetAccessPointResult(GetAccessPointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccessPointResult(
            aws_egress_private_link_endpoints=self.aws_egress_private_link_endpoints,
            azure_egress_private_link_endpoints=self.azure_egress_private_link_endpoints,
            display_name=self.display_name,
            environment=self.environment,
            gateways=self.gateways,
            id=self.id)


def get_access_point(environment: Optional[pulumi.InputType['GetAccessPointEnvironmentArgs']] = None,
                     id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccessPointResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `AccessPoint` describes a Access Point data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_access_point(id="ap-abc123",
        environment=confluentcloud.GetAccessPointEnvironmentArgs(
            id="env-123abc",
        ))
    pulumi.export("accessPoint", main)
    ```


    :param str id: The ID of the Access Point, for example, `ap-abc123`.
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getAccessPoint:getAccessPoint', __args__, opts=opts, typ=GetAccessPointResult).value

    return AwaitableGetAccessPointResult(
        aws_egress_private_link_endpoints=pulumi.get(__ret__, 'aws_egress_private_link_endpoints'),
        azure_egress_private_link_endpoints=pulumi.get(__ret__, 'azure_egress_private_link_endpoints'),
        display_name=pulumi.get(__ret__, 'display_name'),
        environment=pulumi.get(__ret__, 'environment'),
        gateways=pulumi.get(__ret__, 'gateways'),
        id=pulumi.get(__ret__, 'id'))


@_utilities.lift_output_func(get_access_point)
def get_access_point_output(environment: Optional[pulumi.Input[pulumi.InputType['GetAccessPointEnvironmentArgs']]] = None,
                            id: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccessPointResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `AccessPoint` describes a Access Point data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_access_point(id="ap-abc123",
        environment=confluentcloud.GetAccessPointEnvironmentArgs(
            id="env-123abc",
        ))
    pulumi.export("accessPoint", main)
    ```


    :param str id: The ID of the Access Point, for example, `ap-abc123`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KafkaMirrorTopicArgs', 'KafkaMirrorTopic']

@pulumi.input_type
class KafkaMirrorTopicArgs:
    def __init__(__self__, *,
                 cluster_link: pulumi.Input['KafkaMirrorTopicClusterLinkArgs'],
                 kafka_cluster: pulumi.Input['KafkaMirrorTopicKafkaClusterArgs'],
                 source_kafka_topic: pulumi.Input['KafkaMirrorTopicSourceKafkaTopicArgs'],
                 mirror_topic_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a KafkaMirrorTopic resource.
        :param pulumi.Input[str] mirror_topic_name: The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        pulumi.set(__self__, "cluster_link", cluster_link)
        pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        pulumi.set(__self__, "source_kafka_topic", source_kafka_topic)
        if mirror_topic_name is not None:
            pulumi.set(__self__, "mirror_topic_name", mirror_topic_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="clusterLink")
    def cluster_link(self) -> pulumi.Input['KafkaMirrorTopicClusterLinkArgs']:
        return pulumi.get(self, "cluster_link")

    @cluster_link.setter
    def cluster_link(self, value: pulumi.Input['KafkaMirrorTopicClusterLinkArgs']):
        pulumi.set(self, "cluster_link", value)

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> pulumi.Input['KafkaMirrorTopicKafkaClusterArgs']:
        return pulumi.get(self, "kafka_cluster")

    @kafka_cluster.setter
    def kafka_cluster(self, value: pulumi.Input['KafkaMirrorTopicKafkaClusterArgs']):
        pulumi.set(self, "kafka_cluster", value)

    @property
    @pulumi.getter(name="sourceKafkaTopic")
    def source_kafka_topic(self) -> pulumi.Input['KafkaMirrorTopicSourceKafkaTopicArgs']:
        return pulumi.get(self, "source_kafka_topic")

    @source_kafka_topic.setter
    def source_kafka_topic(self, value: pulumi.Input['KafkaMirrorTopicSourceKafkaTopicArgs']):
        pulumi.set(self, "source_kafka_topic", value)

    @property
    @pulumi.getter(name="mirrorTopicName")
    def mirror_topic_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        return pulumi.get(self, "mirror_topic_name")

    @mirror_topic_name.setter
    def mirror_topic_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mirror_topic_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _KafkaMirrorTopicState:
    def __init__(__self__, *,
                 cluster_link: Optional[pulumi.Input['KafkaMirrorTopicClusterLinkArgs']] = None,
                 kafka_cluster: Optional[pulumi.Input['KafkaMirrorTopicKafkaClusterArgs']] = None,
                 mirror_topic_name: Optional[pulumi.Input[str]] = None,
                 source_kafka_topic: Optional[pulumi.Input['KafkaMirrorTopicSourceKafkaTopicArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering KafkaMirrorTopic resources.
        :param pulumi.Input[str] mirror_topic_name: The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        if cluster_link is not None:
            pulumi.set(__self__, "cluster_link", cluster_link)
        if kafka_cluster is not None:
            pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        if mirror_topic_name is not None:
            pulumi.set(__self__, "mirror_topic_name", mirror_topic_name)
        if source_kafka_topic is not None:
            pulumi.set(__self__, "source_kafka_topic", source_kafka_topic)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="clusterLink")
    def cluster_link(self) -> Optional[pulumi.Input['KafkaMirrorTopicClusterLinkArgs']]:
        return pulumi.get(self, "cluster_link")

    @cluster_link.setter
    def cluster_link(self, value: Optional[pulumi.Input['KafkaMirrorTopicClusterLinkArgs']]):
        pulumi.set(self, "cluster_link", value)

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> Optional[pulumi.Input['KafkaMirrorTopicKafkaClusterArgs']]:
        return pulumi.get(self, "kafka_cluster")

    @kafka_cluster.setter
    def kafka_cluster(self, value: Optional[pulumi.Input['KafkaMirrorTopicKafkaClusterArgs']]):
        pulumi.set(self, "kafka_cluster", value)

    @property
    @pulumi.getter(name="mirrorTopicName")
    def mirror_topic_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        return pulumi.get(self, "mirror_topic_name")

    @mirror_topic_name.setter
    def mirror_topic_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mirror_topic_name", value)

    @property
    @pulumi.getter(name="sourceKafkaTopic")
    def source_kafka_topic(self) -> Optional[pulumi.Input['KafkaMirrorTopicSourceKafkaTopicArgs']]:
        return pulumi.get(self, "source_kafka_topic")

    @source_kafka_topic.setter
    def source_kafka_topic(self, value: Optional[pulumi.Input['KafkaMirrorTopicSourceKafkaTopicArgs']]):
        pulumi.set(self, "source_kafka_topic", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class KafkaMirrorTopic(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_link: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicClusterLinkArgs']]] = None,
                 kafka_cluster: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicKafkaClusterArgs']]] = None,
                 mirror_topic_name: Optional[pulumi.Input[str]] = None,
                 source_kafka_topic: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicSourceKafkaTopicArgs']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        example = confluentcloud.KafkaMirrorTopic("example",
            source_kafka_topic=confluentcloud.KafkaMirrorTopicSourceKafkaTopicArgs(
                topic_name="orders",
            ),
            cluster_link=confluentcloud.KafkaMirrorTopicClusterLinkArgs(
                link_name=source_outbound["linkName"],
            ),
            kafka_cluster=confluentcloud.KafkaMirrorTopicKafkaClusterArgs(
                id=destination["id"],
                rest_endpoint=destination["restEndpoint"],
                credentials=confluentcloud.KafkaMirrorTopicKafkaClusterCredentialsArgs(
                    key=app_manager_destination_cluster_api_key["id"],
                    secret=app_manager_destination_cluster_api_key["secret"],
                ),
            ))
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `KafkaMirrorTopic` resource:
          * `destination-initiated-cluster-link-rbac`: An example of setting up a _destination_ initiated cluster link with a mirror topic
          * `source-initiated-cluster-link-rbac`: An example of setting up a _source_ initiated cluster link with a mirror topic

        See [Mirror Topics on Confluent Cloud](https://docs.confluent.io/cloud/current/multi-cloud/cluster-linking/mirror-topics-cc.html) to learn more about Mirror Topics on Confluent Cloud.

        ## Import

        You can import a Kafka mirror topic by using the Kafka cluster ID, cluster link name, and Kafka topic name in the format `<Kafka cluster ID>/<Cluster link name>/<Kafka topic name>`, for example:

        $ export IMPORT_KAFKA_API_KEY="<kafka_api_key>"

        $ export IMPORT_KAFKA_API_SECRET="<kafka_api_secret>"

        $ export IMPORT_KAFKA_REST_ENDPOINT="<kafka_rest_endpoint>"

        ```sh
        $ pulumi import confluentcloud:index/kafkaMirrorTopic:KafkaMirrorTopic my_mirror_topic lkc-abc123/my-cluster-link/orders-123
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] mirror_topic_name: The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KafkaMirrorTopicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        example = confluentcloud.KafkaMirrorTopic("example",
            source_kafka_topic=confluentcloud.KafkaMirrorTopicSourceKafkaTopicArgs(
                topic_name="orders",
            ),
            cluster_link=confluentcloud.KafkaMirrorTopicClusterLinkArgs(
                link_name=source_outbound["linkName"],
            ),
            kafka_cluster=confluentcloud.KafkaMirrorTopicKafkaClusterArgs(
                id=destination["id"],
                rest_endpoint=destination["restEndpoint"],
                credentials=confluentcloud.KafkaMirrorTopicKafkaClusterCredentialsArgs(
                    key=app_manager_destination_cluster_api_key["id"],
                    secret=app_manager_destination_cluster_api_key["secret"],
                ),
            ))
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `KafkaMirrorTopic` resource:
          * `destination-initiated-cluster-link-rbac`: An example of setting up a _destination_ initiated cluster link with a mirror topic
          * `source-initiated-cluster-link-rbac`: An example of setting up a _source_ initiated cluster link with a mirror topic

        See [Mirror Topics on Confluent Cloud](https://docs.confluent.io/cloud/current/multi-cloud/cluster-linking/mirror-topics-cc.html) to learn more about Mirror Topics on Confluent Cloud.

        ## Import

        You can import a Kafka mirror topic by using the Kafka cluster ID, cluster link name, and Kafka topic name in the format `<Kafka cluster ID>/<Cluster link name>/<Kafka topic name>`, for example:

        $ export IMPORT_KAFKA_API_KEY="<kafka_api_key>"

        $ export IMPORT_KAFKA_API_SECRET="<kafka_api_secret>"

        $ export IMPORT_KAFKA_REST_ENDPOINT="<kafka_rest_endpoint>"

        ```sh
        $ pulumi import confluentcloud:index/kafkaMirrorTopic:KafkaMirrorTopic my_mirror_topic lkc-abc123/my-cluster-link/orders-123
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param KafkaMirrorTopicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KafkaMirrorTopicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_link: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicClusterLinkArgs']]] = None,
                 kafka_cluster: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicKafkaClusterArgs']]] = None,
                 mirror_topic_name: Optional[pulumi.Input[str]] = None,
                 source_kafka_topic: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicSourceKafkaTopicArgs']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KafkaMirrorTopicArgs.__new__(KafkaMirrorTopicArgs)

            if cluster_link is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_link'")
            __props__.__dict__["cluster_link"] = cluster_link
            if kafka_cluster is None and not opts.urn:
                raise TypeError("Missing required property 'kafka_cluster'")
            __props__.__dict__["kafka_cluster"] = kafka_cluster
            __props__.__dict__["mirror_topic_name"] = mirror_topic_name
            if source_kafka_topic is None and not opts.urn:
                raise TypeError("Missing required property 'source_kafka_topic'")
            __props__.__dict__["source_kafka_topic"] = source_kafka_topic
            __props__.__dict__["status"] = status
        super(KafkaMirrorTopic, __self__).__init__(
            'confluentcloud:index/kafkaMirrorTopic:KafkaMirrorTopic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_link: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicClusterLinkArgs']]] = None,
            kafka_cluster: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicKafkaClusterArgs']]] = None,
            mirror_topic_name: Optional[pulumi.Input[str]] = None,
            source_kafka_topic: Optional[pulumi.Input[pulumi.InputType['KafkaMirrorTopicSourceKafkaTopicArgs']]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'KafkaMirrorTopic':
        """
        Get an existing KafkaMirrorTopic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] mirror_topic_name: The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KafkaMirrorTopicState.__new__(_KafkaMirrorTopicState)

        __props__.__dict__["cluster_link"] = cluster_link
        __props__.__dict__["kafka_cluster"] = kafka_cluster
        __props__.__dict__["mirror_topic_name"] = mirror_topic_name
        __props__.__dict__["source_kafka_topic"] = source_kafka_topic
        __props__.__dict__["status"] = status
        return KafkaMirrorTopic(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterLink")
    def cluster_link(self) -> pulumi.Output['outputs.KafkaMirrorTopicClusterLink']:
        return pulumi.get(self, "cluster_link")

    @property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> pulumi.Output['outputs.KafkaMirrorTopicKafkaCluster']:
        return pulumi.get(self, "kafka_cluster")

    @property
    @pulumi.getter(name="mirrorTopicName")
    def mirror_topic_name(self) -> pulumi.Output[str]:
        """
        The name of the mirror topic. Only required when there is a prefix configured on the cluster link. For example, when `<prefix>` is configured for the cluster link, the mirror topic name has to be of the format `<prefix><source_topic_name>`.
        """
        return pulumi.get(self, "mirror_topic_name")

    @property
    @pulumi.getter(name="sourceKafkaTopic")
    def source_kafka_topic(self) -> pulumi.Output['outputs.KafkaMirrorTopicSourceKafkaTopic']:
        return pulumi.get(self, "source_kafka_topic")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetSchemaRegistryRegionResult',
    'AwaitableGetSchemaRegistryRegionResult',
    'get_schema_registry_region',
    'get_schema_registry_region_output',
]

@pulumi.output_type
class GetSchemaRegistryRegionResult:
    """
    A collection of values returned by getSchemaRegistryRegion.
    """
    def __init__(__self__, cloud=None, id=None, package=None, region=None):
        if cloud and not isinstance(cloud, str):
            raise TypeError("Expected argument 'cloud' to be a str")
        pulumi.set(__self__, "cloud", cloud)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if package and not isinstance(package, str):
            raise TypeError("Expected argument 'package' to be a str")
        pulumi.set(__self__, "package", package)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @property
    @pulumi.getter
    def cloud(self) -> str:
        return pulumi.get(self, "cloud")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the Schema Registry region, for example, `sgreg-1`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def package(self) -> str:
        return pulumi.get(self, "package")

    @property
    @pulumi.getter
    def region(self) -> str:
        return pulumi.get(self, "region")


class AwaitableGetSchemaRegistryRegionResult(GetSchemaRegistryRegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSchemaRegistryRegionResult(
            cloud=self.cloud,
            id=self.id,
            package=self.package,
            region=self.region)


def get_schema_registry_region(cloud: Optional[str] = None,
                               package: Optional[str] = None,
                               region: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSchemaRegistryRegionResult:
    """
    [![Deprecated](https://img.shields.io/badge/Lifecycle%20Stage-Deprecated-yellow)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_schema_registry_region` describes a Schema Registry cluster data source.

    !> **Warning:** The `get_schema_registry_region` data source has been deprecated and will be removed in the next major version of the provider (2.0.0).
    Refer to the Upgrade Guide for more details.
    The guide will be published once version 2.0.0 is released.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_schema_registry_region(cloud="AWS",
        region="us-east-2",
        package="ESSENTIALS")
    pulumi.export("example", example)
    ```


    :param str cloud: The cloud service provider that hosts the region. Accepted values are: `AWS`, `AZURE`, and `GCP`.
    :param str package: The type of the billing package. Accepted values are: `ESSENTIALS` and `ADVANCED`.
           
           > **Note:** See [Schema Registry Regions](https://docs.confluent.io/cloud/current/stream-governance/packages.html#stream-governance-regions) to manually find a corresponding region ID based on desired cloud provider region and types of the billing package.
    :param str region: The cloud service provider region, for example, `us-east-2`. See [Cloud Providers and Regions](https://docs.confluent.io/cloud/current/clusters/regions.html#cloud-providers-and-regions) for a full list of options for AWS, Azure, and GCP.
    """
    __args__ = dict()
    __args__['cloud'] = cloud
    __args__['package'] = package
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getSchemaRegistryRegion:getSchemaRegistryRegion', __args__, opts=opts, typ=GetSchemaRegistryRegionResult).value

    return AwaitableGetSchemaRegistryRegionResult(
        cloud=pulumi.get(__ret__, 'cloud'),
        id=pulumi.get(__ret__, 'id'),
        package=pulumi.get(__ret__, 'package'),
        region=pulumi.get(__ret__, 'region'))


@_utilities.lift_output_func(get_schema_registry_region)
def get_schema_registry_region_output(cloud: Optional[pulumi.Input[str]] = None,
                                      package: Optional[pulumi.Input[str]] = None,
                                      region: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSchemaRegistryRegionResult]:
    """
    [![Deprecated](https://img.shields.io/badge/Lifecycle%20Stage-Deprecated-yellow)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_schema_registry_region` describes a Schema Registry cluster data source.

    !> **Warning:** The `get_schema_registry_region` data source has been deprecated and will be removed in the next major version of the provider (2.0.0).
    Refer to the Upgrade Guide for more details.
    The guide will be published once version 2.0.0 is released.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_schema_registry_region(cloud="AWS",
        region="us-east-2",
        package="ESSENTIALS")
    pulumi.export("example", example)
    ```


    :param str cloud: The cloud service provider that hosts the region. Accepted values are: `AWS`, `AZURE`, and `GCP`.
    :param str package: The type of the billing package. Accepted values are: `ESSENTIALS` and `ADVANCED`.
           
           > **Note:** See [Schema Registry Regions](https://docs.confluent.io/cloud/current/stream-governance/packages.html#stream-governance-regions) to manually find a corresponding region ID based on desired cloud provider region and types of the billing package.
    :param str region: The cloud service provider region, for example, `us-east-2`. See [Cloud Providers and Regions](https://docs.confluent.io/cloud/current/clusters/regions.html#cloud-providers-and-regions) for a full list of options for AWS, Azure, and GCP.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetKafkaClusterResult',
    'AwaitableGetKafkaClusterResult',
    'get_kafka_cluster',
    'get_kafka_cluster_output',
]

@pulumi.output_type
class GetKafkaClusterResult:
    """
    A collection of values returned by getKafkaCluster.
    """
    def __init__(__self__, api_version=None, availability=None, basics=None, bootstrap_endpoint=None, byok_keys=None, cloud=None, dedicated=None, display_name=None, enterprises=None, environment=None, freights=None, id=None, kind=None, networks=None, rbac_crn=None, region=None, rest_endpoint=None, standards=None):
        if api_version and not isinstance(api_version, str):
            raise TypeError("Expected argument 'api_version' to be a str")
        pulumi.set(__self__, "api_version", api_version)
        if availability and not isinstance(availability, str):
            raise TypeError("Expected argument 'availability' to be a str")
        pulumi.set(__self__, "availability", availability)
        if basics and not isinstance(basics, list):
            raise TypeError("Expected argument 'basics' to be a list")
        pulumi.set(__self__, "basics", basics)
        if bootstrap_endpoint and not isinstance(bootstrap_endpoint, str):
            raise TypeError("Expected argument 'bootstrap_endpoint' to be a str")
        pulumi.set(__self__, "bootstrap_endpoint", bootstrap_endpoint)
        if byok_keys and not isinstance(byok_keys, list):
            raise TypeError("Expected argument 'byok_keys' to be a list")
        pulumi.set(__self__, "byok_keys", byok_keys)
        if cloud and not isinstance(cloud, str):
            raise TypeError("Expected argument 'cloud' to be a str")
        pulumi.set(__self__, "cloud", cloud)
        if dedicated and not isinstance(dedicated, dict):
            raise TypeError("Expected argument 'dedicated' to be a dict")
        pulumi.set(__self__, "dedicated", dedicated)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if enterprises and not isinstance(enterprises, list):
            raise TypeError("Expected argument 'enterprises' to be a list")
        pulumi.set(__self__, "enterprises", enterprises)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if freights and not isinstance(freights, list):
            raise TypeError("Expected argument 'freights' to be a list")
        pulumi.set(__self__, "freights", freights)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if networks and not isinstance(networks, list):
            raise TypeError("Expected argument 'networks' to be a list")
        pulumi.set(__self__, "networks", networks)
        if rbac_crn and not isinstance(rbac_crn, str):
            raise TypeError("Expected argument 'rbac_crn' to be a str")
        pulumi.set(__self__, "rbac_crn", rbac_crn)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if rest_endpoint and not isinstance(rest_endpoint, str):
            raise TypeError("Expected argument 'rest_endpoint' to be a str")
        pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if standards and not isinstance(standards, list):
            raise TypeError("Expected argument 'standards' to be a list")
        pulumi.set(__self__, "standards", standards)

    @property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> str:
        """
        (Required String) An API Version of the schema version of the Kafka cluster, for example, `cmk/v2`.
        """
        return pulumi.get(self, "api_version")

    @property
    @pulumi.getter
    def availability(self) -> str:
        """
        (Required String) The availability zone configuration of the Kafka cluster. Accepted values are: `SINGLE_ZONE`, `MULTI_ZONE`, `LOW`, and `HIGH`.
        """
        return pulumi.get(self, "availability")

    @property
    @pulumi.getter
    def basics(self) -> Optional[Sequence['outputs.GetKafkaClusterBasicResult']]:
        """
        (Optional Configuration Block) The configuration of the Basic Kafka cluster.
        """
        return pulumi.get(self, "basics")

    @property
    @pulumi.getter(name="bootstrapEndpoint")
    def bootstrap_endpoint(self) -> str:
        """
        (Required String) The bootstrap endpoint used by Kafka clients to connect to the Kafka cluster. (e.g., `pkc-00000.us-central1.gcp.confluent.cloud:9092`).
        """
        return pulumi.get(self, "bootstrap_endpoint")

    @property
    @pulumi.getter(name="byokKeys")
    def byok_keys(self) -> Sequence['outputs.GetKafkaClusterByokKeyResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "byok_keys")

    @property
    @pulumi.getter
    def cloud(self) -> str:
        """
        (Required String) The cloud service provider that runs the Kafka cluster. Accepted values are: `AWS`, `AZURE`, and `GCP`.
        """
        return pulumi.get(self, "cloud")

    @property
    @pulumi.getter
    def dedicated(self) -> Optional['outputs.GetKafkaClusterDedicatedResult']:
        """
        (Optional Configuration Block) The configuration of the Dedicated Kafka cluster. It supports the following:
        """
        return pulumi.get(self, "dedicated")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        (Required String) The name of the Kafka cluster.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def enterprises(self) -> Optional[Sequence['outputs.GetKafkaClusterEnterpriseResult']]:
        """
        (Optional Configuration Block) The configuration of the Enterprise Kafka cluster.
        """
        return pulumi.get(self, "enterprises")

    @property
    @pulumi.getter
    def environment(self) -> 'outputs.GetKafkaClusterEnvironmentResult':
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter
    def freights(self) -> Optional[Sequence['outputs.GetKafkaClusterFreightResult']]:
        """
        (Optional Configuration Block) The configuration of the Freight Kafka cluster.
        """
        return pulumi.get(self, "freights")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the Confluent key that is used to encrypt the data in the Kafka cluster, for example, `cck-lye5m`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def kind(self) -> str:
        """
        (Required String) A kind of the Kafka cluster, for example, `Cluster`.
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter
    def networks(self) -> Sequence['outputs.GetKafkaClusterNetworkResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter(name="rbacCrn")
    def rbac_crn(self) -> str:
        """
        (Required String) The Confluent Resource Name of the Kafka cluster, for example, `crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa/environment=env-abc123/cloud-cluster=lkc-abc123`.
        """
        return pulumi.get(self, "rbac_crn")

    @property
    @pulumi.getter
    def region(self) -> str:
        """
        (Required String) The cloud service provider region where the Kafka cluster is running, for example, `us-west-2`. See [Cloud Providers and Regions](https://docs.confluent.io/cloud/current/clusters/regions.html#cloud-providers-and-regions) for a full list of options for AWS, Azure, and GCP.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> str:
        """
        (Required String) The REST endpoint of the Kafka cluster (e.g., `https://pkc-00000.us-central1.gcp.confluent.cloud:443`).
        """
        return pulumi.get(self, "rest_endpoint")

    @property
    @pulumi.getter
    def standards(self) -> Optional[Sequence['outputs.GetKafkaClusterStandardResult']]:
        """
        (Optional Configuration Block) The configuration of the Standard Kafka cluster.
        """
        return pulumi.get(self, "standards")


class AwaitableGetKafkaClusterResult(GetKafkaClusterResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKafkaClusterResult(
            api_version=self.api_version,
            availability=self.availability,
            basics=self.basics,
            bootstrap_endpoint=self.bootstrap_endpoint,
            byok_keys=self.byok_keys,
            cloud=self.cloud,
            dedicated=self.dedicated,
            display_name=self.display_name,
            enterprises=self.enterprises,
            environment=self.environment,
            freights=self.freights,
            id=self.id,
            kind=self.kind,
            networks=self.networks,
            rbac_crn=self.rbac_crn,
            region=self.region,
            rest_endpoint=self.rest_endpoint,
            standards=self.standards)


def get_kafka_cluster(basics: Optional[Sequence[pulumi.InputType['GetKafkaClusterBasicArgs']]] = None,
                      dedicated: Optional[pulumi.InputType['GetKafkaClusterDedicatedArgs']] = None,
                      display_name: Optional[str] = None,
                      enterprises: Optional[Sequence[pulumi.InputType['GetKafkaClusterEnterpriseArgs']]] = None,
                      environment: Optional[pulumi.InputType['GetKafkaClusterEnvironmentArgs']] = None,
                      freights: Optional[Sequence[pulumi.InputType['GetKafkaClusterFreightArgs']]] = None,
                      id: Optional[str] = None,
                      standards: Optional[Sequence[pulumi.InputType['GetKafkaClusterStandardArgs']]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKafkaClusterResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `KafkaCluster` describes a Kafka cluster data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example_using_id = confluentcloud.get_kafka_cluster(id="lkc-abc123",
        environment=confluentcloud.GetKafkaClusterEnvironmentArgs(
            id="env-xyz456",
        ))
    test_sa = confluentcloud.ServiceAccount("test-sa",
        display_name="app_mgr",
        description=f"app_mgr for {example_using_id.display_name}")
    example_using_name = confluentcloud.get_kafka_cluster(display_name="basic_kafka_cluster",
        environment=confluentcloud.GetKafkaClusterEnvironmentArgs(
            id="env-xyz456",
        ))
    pulumi.export("exampleUsingName", example_using_name)
    ```


    :param Sequence[pulumi.InputType['GetKafkaClusterBasicArgs']] basics: (Optional Configuration Block) The configuration of the Basic Kafka cluster.
    :param pulumi.InputType['GetKafkaClusterDedicatedArgs'] dedicated: (Optional Configuration Block) The configuration of the Dedicated Kafka cluster. It supports the following:
    :param str display_name: A human-readable name for the Kafka cluster.
    :param Sequence[pulumi.InputType['GetKafkaClusterEnterpriseArgs']] enterprises: (Optional Configuration Block) The configuration of the Enterprise Kafka cluster.
    :param Sequence[pulumi.InputType['GetKafkaClusterFreightArgs']] freights: (Optional Configuration Block) The configuration of the Freight Kafka cluster.
    :param str id: The ID of the Kafka cluster, for example, `lkc-abc123`.
    :param Sequence[pulumi.InputType['GetKafkaClusterStandardArgs']] standards: (Optional Configuration Block) The configuration of the Standard Kafka cluster.
    """
    __args__ = dict()
    __args__['basics'] = basics
    __args__['dedicated'] = dedicated
    __args__['displayName'] = display_name
    __args__['enterprises'] = enterprises
    __args__['environment'] = environment
    __args__['freights'] = freights
    __args__['id'] = id
    __args__['standards'] = standards
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getKafkaCluster:getKafkaCluster', __args__, opts=opts, typ=GetKafkaClusterResult).value

    return AwaitableGetKafkaClusterResult(
        api_version=pulumi.get(__ret__, 'api_version'),
        availability=pulumi.get(__ret__, 'availability'),
        basics=pulumi.get(__ret__, 'basics'),
        bootstrap_endpoint=pulumi.get(__ret__, 'bootstrap_endpoint'),
        byok_keys=pulumi.get(__ret__, 'byok_keys'),
        cloud=pulumi.get(__ret__, 'cloud'),
        dedicated=pulumi.get(__ret__, 'dedicated'),
        display_name=pulumi.get(__ret__, 'display_name'),
        enterprises=pulumi.get(__ret__, 'enterprises'),
        environment=pulumi.get(__ret__, 'environment'),
        freights=pulumi.get(__ret__, 'freights'),
        id=pulumi.get(__ret__, 'id'),
        kind=pulumi.get(__ret__, 'kind'),
        networks=pulumi.get(__ret__, 'networks'),
        rbac_crn=pulumi.get(__ret__, 'rbac_crn'),
        region=pulumi.get(__ret__, 'region'),
        rest_endpoint=pulumi.get(__ret__, 'rest_endpoint'),
        standards=pulumi.get(__ret__, 'standards'))


@_utilities.lift_output_func(get_kafka_cluster)
def get_kafka_cluster_output(basics: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetKafkaClusterBasicArgs']]]]] = None,
                             dedicated: Optional[pulumi.Input[Optional[pulumi.InputType['GetKafkaClusterDedicatedArgs']]]] = None,
                             display_name: Optional[pulumi.Input[Optional[str]]] = None,
                             enterprises: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetKafkaClusterEnterpriseArgs']]]]] = None,
                             environment: Optional[pulumi.Input[pulumi.InputType['GetKafkaClusterEnvironmentArgs']]] = None,
                             freights: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetKafkaClusterFreightArgs']]]]] = None,
                             id: Optional[pulumi.Input[Optional[str]]] = None,
                             standards: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetKafkaClusterStandardArgs']]]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetKafkaClusterResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `KafkaCluster` describes a Kafka cluster data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example_using_id = confluentcloud.get_kafka_cluster(id="lkc-abc123",
        environment=confluentcloud.GetKafkaClusterEnvironmentArgs(
            id="env-xyz456",
        ))
    test_sa = confluentcloud.ServiceAccount("test-sa",
        display_name="app_mgr",
        description=f"app_mgr for {example_using_id.display_name}")
    example_using_name = confluentcloud.get_kafka_cluster(display_name="basic_kafka_cluster",
        environment=confluentcloud.GetKafkaClusterEnvironmentArgs(
            id="env-xyz456",
        ))
    pulumi.export("exampleUsingName", example_using_name)
    ```


    :param Sequence[pulumi.InputType['GetKafkaClusterBasicArgs']] basics: (Optional Configuration Block) The configuration of the Basic Kafka cluster.
    :param pulumi.InputType['GetKafkaClusterDedicatedArgs'] dedicated: (Optional Configuration Block) The configuration of the Dedicated Kafka cluster. It supports the following:
    :param str display_name: A human-readable name for the Kafka cluster.
    :param Sequence[pulumi.InputType['GetKafkaClusterEnterpriseArgs']] enterprises: (Optional Configuration Block) The configuration of the Enterprise Kafka cluster.
    :param Sequence[pulumi.InputType['GetKafkaClusterFreightArgs']] freights: (Optional Configuration Block) The configuration of the Freight Kafka cluster.
    :param str id: The ID of the Kafka cluster, for example, `lkc-abc123`.
    :param Sequence[pulumi.InputType['GetKafkaClusterStandardArgs']] standards: (Optional Configuration Block) The configuration of the Standard Kafka cluster.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['IdentityProviderArgs', 'IdentityProvider']

@pulumi.input_type
class IdentityProviderArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 issuer: pulumi.Input[str],
                 jwks_uri: pulumi.Input[str]):
        """
        The set of arguments for constructing a IdentityProvider resource.
        :param pulumi.Input[str] description: A description for the Identity Provider.
        :param pulumi.Input[str] display_name: A human-readable name for the Identity Provider.
        :param pulumi.Input[str] issuer: A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        :param pulumi.Input[str] jwks_uri: A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.
               
               > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "issuer", issuer)
        pulumi.set(__self__, "jwks_uri", jwks_uri)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Input[str]:
        """
        A description for the Identity Provider.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[str]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        A human-readable name for the Identity Provider.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def issuer(self) -> pulumi.Input[str]:
        """
        A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        """
        return pulumi.get(self, "issuer")

    @issuer.setter
    def issuer(self, value: pulumi.Input[str]):
        pulumi.set(self, "issuer", value)

    @property
    @pulumi.getter(name="jwksUri")
    def jwks_uri(self) -> pulumi.Input[str]:
        """
        A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.

        > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        return pulumi.get(self, "jwks_uri")

    @jwks_uri.setter
    def jwks_uri(self, value: pulumi.Input[str]):
        pulumi.set(self, "jwks_uri", value)


@pulumi.input_type
class _IdentityProviderState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 issuer: Optional[pulumi.Input[str]] = None,
                 jwks_uri: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IdentityProvider resources.
        :param pulumi.Input[str] description: A description for the Identity Provider.
        :param pulumi.Input[str] display_name: A human-readable name for the Identity Provider.
        :param pulumi.Input[str] issuer: A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        :param pulumi.Input[str] jwks_uri: A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.
               
               > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if issuer is not None:
            pulumi.set(__self__, "issuer", issuer)
        if jwks_uri is not None:
            pulumi.set(__self__, "jwks_uri", jwks_uri)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A description for the Identity Provider.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-readable name for the Identity Provider.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def issuer(self) -> Optional[pulumi.Input[str]]:
        """
        A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        """
        return pulumi.get(self, "issuer")

    @issuer.setter
    def issuer(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "issuer", value)

    @property
    @pulumi.getter(name="jwksUri")
    def jwks_uri(self) -> Optional[pulumi.Input[str]]:
        """
        A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.

        > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        return pulumi.get(self, "jwks_uri")

    @jwks_uri.setter
    def jwks_uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "jwks_uri", value)


class IdentityProvider(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 issuer: Optional[pulumi.Input[str]] = None,
                 jwks_uri: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

        `IdentityProvider` provides an Identity Provider resource that enables creating, editing, and deleting identity providers on Confluent Cloud.

        ## Example Usage

        ### Example Identity Provider: Azure AD

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        azure = confluentcloud.IdentityProvider("azure",
            display_name="My OIDC Provider: Azure AD",
            description="My description",
            issuer="https://login.microsoftonline.com/{tenant_id}/v2.0",
            jwks_uri="https://login.microsoftonline.com/common/discovery/v2.0/keys")
        ```

        ### Example Identity Provider: Okta

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        okta = confluentcloud.IdentityProvider("okta",
            display_name="My OIDC Provider: Okta",
            description="My description",
            issuer="https://mycompany.okta.com/oauth2/default",
            jwks_uri="https://mycompany.okta.com/oauth2/default/v1/keys")
        ```

        ## External Documentation

        * [Authenticating with OAuth](https://docs.confluent.io/cloud/current/access-management/authenticate/oauth/overview.html).

        ## Import

        You can import an Identity Provider by using Identity Provider ID, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/identityProvider:IdentityProvider example op-abc123
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A description for the Identity Provider.
        :param pulumi.Input[str] display_name: A human-readable name for the Identity Provider.
        :param pulumi.Input[str] issuer: A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        :param pulumi.Input[str] jwks_uri: A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.
               
               > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IdentityProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

        `IdentityProvider` provides an Identity Provider resource that enables creating, editing, and deleting identity providers on Confluent Cloud.

        ## Example Usage

        ### Example Identity Provider: Azure AD

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        azure = confluentcloud.IdentityProvider("azure",
            display_name="My OIDC Provider: Azure AD",
            description="My description",
            issuer="https://login.microsoftonline.com/{tenant_id}/v2.0",
            jwks_uri="https://login.microsoftonline.com/common/discovery/v2.0/keys")
        ```

        ### Example Identity Provider: Okta

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        okta = confluentcloud.IdentityProvider("okta",
            display_name="My OIDC Provider: Okta",
            description="My description",
            issuer="https://mycompany.okta.com/oauth2/default",
            jwks_uri="https://mycompany.okta.com/oauth2/default/v1/keys")
        ```

        ## External Documentation

        * [Authenticating with OAuth](https://docs.confluent.io/cloud/current/access-management/authenticate/oauth/overview.html).

        ## Import

        You can import an Identity Provider by using Identity Provider ID, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/identityProvider:IdentityProvider example op-abc123
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param IdentityProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IdentityProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 issuer: Optional[pulumi.Input[str]] = None,
                 jwks_uri: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IdentityProviderArgs.__new__(IdentityProviderArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if issuer is None and not opts.urn:
                raise TypeError("Missing required property 'issuer'")
            __props__.__dict__["issuer"] = issuer
            if jwks_uri is None and not opts.urn:
                raise TypeError("Missing required property 'jwks_uri'")
            __props__.__dict__["jwks_uri"] = jwks_uri
        super(IdentityProvider, __self__).__init__(
            'confluentcloud:index/identityProvider:IdentityProvider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            issuer: Optional[pulumi.Input[str]] = None,
            jwks_uri: Optional[pulumi.Input[str]] = None) -> 'IdentityProvider':
        """
        Get an existing IdentityProvider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A description for the Identity Provider.
        :param pulumi.Input[str] display_name: A human-readable name for the Identity Provider.
        :param pulumi.Input[str] issuer: A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        :param pulumi.Input[str] jwks_uri: A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.
               
               > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IdentityProviderState.__new__(_IdentityProviderState)

        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["issuer"] = issuer
        __props__.__dict__["jwks_uri"] = jwks_uri
        return IdentityProvider(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        A description for the Identity Provider.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        A human-readable name for the Identity Provider.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def issuer(self) -> pulumi.Output[str]:
        """
        A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        """
        return pulumi.get(self, "issuer")

    @property
    @pulumi.getter(name="jwksUri")
    def jwks_uri(self) -> pulumi.Output[str]:
        """
        A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.

        > **Note:** When using Azure AD identity provider, you can find your Azure Tenant ID in the [Azure Portal under Azure Active Directory](https://portal.azure.com/#blade/Microsoft_AAD_IAM/ActiveDirectoryMenuBlade/Overview). Must be a valid **32 character UUID string**.
        """
        return pulumi.get(self, "jwks_uri")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApiKeyArgs', 'ApiKey']

@pulumi.input_type
class ApiKeyArgs:
    def __init__(__self__, *,
                 owner: pulumi.Input['ApiKeyOwnerArgs'],
                 description: Optional[pulumi.Input[str]] = None,
                 disable_wait_for_ready: Optional[pulumi.Input[bool]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 managed_resource: Optional[pulumi.Input['ApiKeyManagedResourceArgs']] = None):
        """
        The set of arguments for constructing a ApiKey resource.
        :param pulumi.Input['ApiKeyOwnerArgs'] owner: The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        :param pulumi.Input[str] description: A free-form description of the API Account.
        :param pulumi.Input[bool] disable_wait_for_ready: An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        :param pulumi.Input[str] display_name: A human-readable name for the API Key.
        :param pulumi.Input['ApiKeyManagedResourceArgs'] managed_resource: The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        """
        pulumi.set(__self__, "owner", owner)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_wait_for_ready is not None:
            pulumi.set(__self__, "disable_wait_for_ready", disable_wait_for_ready)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if managed_resource is not None:
            pulumi.set(__self__, "managed_resource", managed_resource)

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Input['ApiKeyOwnerArgs']:
        """
        The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: pulumi.Input['ApiKeyOwnerArgs']):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A free-form description of the API Account.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableWaitForReady")
    def disable_wait_for_ready(self) -> Optional[pulumi.Input[bool]]:
        """
        An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        """
        return pulumi.get(self, "disable_wait_for_ready")

    @disable_wait_for_ready.setter
    def disable_wait_for_ready(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_wait_for_ready", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-readable name for the API Key.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="managedResource")
    def managed_resource(self) -> Optional[pulumi.Input['ApiKeyManagedResourceArgs']]:
        """
        The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        """
        return pulumi.get(self, "managed_resource")

    @managed_resource.setter
    def managed_resource(self, value: Optional[pulumi.Input['ApiKeyManagedResourceArgs']]):
        pulumi.set(self, "managed_resource", value)


@pulumi.input_type
class _ApiKeyState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_wait_for_ready: Optional[pulumi.Input[bool]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 managed_resource: Optional[pulumi.Input['ApiKeyManagedResourceArgs']] = None,
                 owner: Optional[pulumi.Input['ApiKeyOwnerArgs']] = None,
                 secret: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ApiKey resources.
        :param pulumi.Input[str] description: A free-form description of the API Account.
        :param pulumi.Input[bool] disable_wait_for_ready: An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        :param pulumi.Input[str] display_name: A human-readable name for the API Key.
        :param pulumi.Input['ApiKeyManagedResourceArgs'] managed_resource: The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        :param pulumi.Input['ApiKeyOwnerArgs'] owner: The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        :param pulumi.Input[str] secret: (Required String, Sensitive) The secret of the API Key.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_wait_for_ready is not None:
            pulumi.set(__self__, "disable_wait_for_ready", disable_wait_for_ready)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if managed_resource is not None:
            pulumi.set(__self__, "managed_resource", managed_resource)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A free-form description of the API Account.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="disableWaitForReady")
    def disable_wait_for_ready(self) -> Optional[pulumi.Input[bool]]:
        """
        An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        """
        return pulumi.get(self, "disable_wait_for_ready")

    @disable_wait_for_ready.setter
    def disable_wait_for_ready(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "disable_wait_for_ready", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-readable name for the API Key.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="managedResource")
    def managed_resource(self) -> Optional[pulumi.Input['ApiKeyManagedResourceArgs']]:
        """
        The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        """
        return pulumi.get(self, "managed_resource")

    @managed_resource.setter
    def managed_resource(self, value: Optional[pulumi.Input['ApiKeyManagedResourceArgs']]):
        pulumi.set(self, "managed_resource", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input['ApiKeyOwnerArgs']]:
        """
        The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input['ApiKeyOwnerArgs']]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        (Required String, Sensitive) The secret of the API Key.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)


class ApiKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_wait_for_ready: Optional[pulumi.Input[bool]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 managed_resource: Optional[pulumi.Input[pulumi.InputType['ApiKeyManagedResourceArgs']]] = None,
                 owner: Optional[pulumi.Input[pulumi.InputType['ApiKeyOwnerArgs']]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Example Kafka API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        app_manager_kafka_api_key = confluentcloud.ApiKey("app-manager-kafka-api-key",
            display_name="app-manager-kafka-api-key",
            description="Kafka API Key that is owned by 'app-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=app_manager["id"],
                api_version=app_manager["apiVersion"],
                kind=app_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=basic["id"],
                api_version=basic["apiVersion"],
                kind=basic["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example ksqlDB API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        ksqldb_api_key = confluentcloud.ApiKey("ksqldb-api-key",
            display_name="ksqldb-api-key",
            description="KsqlDB API Key that is owned by 'app-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=app_manager["id"],
                api_version=app_manager["apiVersion"],
                kind=app_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=main["id"],
                api_version=main["apiVersion"],
                kind=main["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example Schema Registry API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        env_manager_schema_registry_api_key = confluentcloud.ApiKey("env-manager-schema-registry-api-key",
            display_name="env-manager-schema-registry-api-key",
            description="Schema Registry API Key that is owned by 'env-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=env_manager["id"],
                api_version=env_manager["apiVersion"],
                kind=env_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=essentials["id"],
                api_version=essentials["apiVersion"],
                kind=essentials["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example Flink API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        env_manager_flink_api_key = confluentcloud.ApiKey("env-manager-flink-api-key",
            display_name="env-manager-flink-api-key",
            description="Flink API Key that is owned by 'env-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=env_manager["id"],
                api_version=env_manager["apiVersion"],
                kind=env_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=example["id"],
                api_version=example["apiVersion"],
                kind=example["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example Cloud API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        env_manager_cloud_api_key = confluentcloud.ApiKey("env-manager-cloud-api-key",
            display_name="env-manager-cloud-api-key",
            description="Cloud API Key that is owned by 'env-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=env_manager["id"],
                api_version=env_manager["apiVersion"],
                kind=env_manager["kind"],
            ))
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `ApiKey` resource:
          * `basic-kafka-acls`: _Basic_ Kafka cluster with authorization using ACLs
          * `basic-kafka-acls-with-alias`: _Basic_ Kafka cluster with authorization using ACLs
          * `standard-kafka-acls`: _Standard_ Kafka cluster with authorization using ACLs
          * `standard-kafka-rbac`: _Standard_ Kafka cluster with authorization using RBAC
          * `dedicated-public-kafka-acls`: _Dedicated_ Kafka cluster that is accessible over the public internet with authorization using ACLs
          * `dedicated-public-kafka-rbac`: _Dedicated_ Kafka cluster that is accessible over the public internet with authorization using RBAC
          * `dedicated-privatelink-aws-kafka-acls`: _Dedicated_ Kafka cluster on AWS that is accessible via PrivateLink connections with authorization using ACLs
          * `dedicated-privatelink-aws-kafka-rbac`: _Dedicated_ Kafka cluster on AWS that is accessible via PrivateLink connections with authorization using RBAC
          * `dedicated-privatelink-azure-kafka-rbac`: _Dedicated_ Kafka cluster on Azure that is accessible via PrivateLink connections with authorization using RBAC
          * `dedicated-privatelink-azure-kafka-acls`: _Dedicated_ Kafka cluster on Azure that is accessible via PrivateLink connections with authorization using ACLs
          * `dedicated-private-service-connect-gcp-kafka-acls`: _Dedicated_ Kafka cluster on GCP that is accessible via Private Service Connect connections with authorization using ACLs
          * `dedicated-private-service-connect-gcp-kafka-rbac`: _Dedicated_ Kafka cluster on GCP that is accessible via Private Service Connect connections with authorization using RBAC
          * `dedicated-vnet-peering-azure-kafka-acls`: _Dedicated_ Kafka cluster on Azure that is accessible via VPC Peering connections with authorization using ACLs
          * `dedicated-vnet-peering-azure-kafka-rbac`: _Dedicated_ Kafka cluster on Azure that is accessible via VPC Peering connections with authorization using RBAC
          * `dedicated-vpc-peering-aws-kafka-acls`: _Dedicated_ Kafka cluster on AWS that is accessible via VPC Peering connections with authorization using ACLs
          * `dedicated-vpc-peering-aws-kafka-rbac`: _Dedicated_ Kafka cluster on AWS that is accessible via VPC Peering connections with authorization using RBAC
          * `dedicated-vpc-peering-gcp-kafka-acls`: _Dedicated_ Kafka cluster on GCP that is accessible via VPC Peering connections with authorization using ACLs
          * `dedicated-vpc-peering-gcp-kafka-rbac`: _Dedicated_ Kafka cluster on GCP that is accessible via VPC Peering connections with authorization using RBAC
          * `dedicated-transit-gateway-attachment-aws-kafka-acls`: _Dedicated_ Kafka cluster on AWS that is accessible via Transit Gateway Endpoint with authorization using ACLs
          * `dedicated-transit-gateway-attachment-aws-kafka-rbac`: _Dedicated_ Kafka cluster on AWS that is accessible via Transit Gateway Endpoint with authorization using RBAC
          * `enterprise-privatelinkattachment-aws-kafka-acls`: _Enterprise_ Kafka cluster on AWS that is accessible via PrivateLink connections with authorization using ACLs

        ## Import

        You can import a Cluster API Key by using the Environment ID and Cluster API Key ID in the format `<Environment ID>/<Cluster API Key ID>`, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        $ export API_KEY_SECRET="<api_key_secret>"

        Option #1: Cluster API Key

        ```sh
        $ pulumi import confluentcloud:index/apiKey:ApiKey example_kafka_api_key "env-abc123/UTT6WDRXX7FHD2GV"
        ```

        You can import a Cloud API Key by using Cloud API Key ID, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        $ export API_KEY_SECRET="<api_key_secret>"

        Option #2: Cloud API Key

        ```sh
        $ pulumi import confluentcloud:index/apiKey:ApiKey example_cloud_api_key "4UEXOMMWIBE5KZQG"
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A free-form description of the API Account.
        :param pulumi.Input[bool] disable_wait_for_ready: An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        :param pulumi.Input[str] display_name: A human-readable name for the API Key.
        :param pulumi.Input[pulumi.InputType['ApiKeyManagedResourceArgs']] managed_resource: The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        :param pulumi.Input[pulumi.InputType['ApiKeyOwnerArgs']] owner: The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Example Kafka API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        app_manager_kafka_api_key = confluentcloud.ApiKey("app-manager-kafka-api-key",
            display_name="app-manager-kafka-api-key",
            description="Kafka API Key that is owned by 'app-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=app_manager["id"],
                api_version=app_manager["apiVersion"],
                kind=app_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=basic["id"],
                api_version=basic["apiVersion"],
                kind=basic["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example ksqlDB API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        ksqldb_api_key = confluentcloud.ApiKey("ksqldb-api-key",
            display_name="ksqldb-api-key",
            description="KsqlDB API Key that is owned by 'app-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=app_manager["id"],
                api_version=app_manager["apiVersion"],
                kind=app_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=main["id"],
                api_version=main["apiVersion"],
                kind=main["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example Schema Registry API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        env_manager_schema_registry_api_key = confluentcloud.ApiKey("env-manager-schema-registry-api-key",
            display_name="env-manager-schema-registry-api-key",
            description="Schema Registry API Key that is owned by 'env-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=env_manager["id"],
                api_version=env_manager["apiVersion"],
                kind=env_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=essentials["id"],
                api_version=essentials["apiVersion"],
                kind=essentials["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example Flink API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        env_manager_flink_api_key = confluentcloud.ApiKey("env-manager-flink-api-key",
            display_name="env-manager-flink-api-key",
            description="Flink API Key that is owned by 'env-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=env_manager["id"],
                api_version=env_manager["apiVersion"],
                kind=env_manager["kind"],
            ),
            managed_resource=confluentcloud.ApiKeyManagedResourceArgs(
                id=example["id"],
                api_version=example["apiVersion"],
                kind=example["kind"],
                environment=confluentcloud.ApiKeyManagedResourceEnvironmentArgs(
                    id=staging["id"],
                ),
            ))
        ```

        ### Example Cloud API Key
        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        env_manager_cloud_api_key = confluentcloud.ApiKey("env-manager-cloud-api-key",
            display_name="env-manager-cloud-api-key",
            description="Cloud API Key that is owned by 'env-manager' service account",
            owner=confluentcloud.ApiKeyOwnerArgs(
                id=env_manager["id"],
                api_version=env_manager["apiVersion"],
                kind=env_manager["kind"],
            ))
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `ApiKey` resource:
          * `basic-kafka-acls`: _Basic_ Kafka cluster with authorization using ACLs
          * `basic-kafka-acls-with-alias`: _Basic_ Kafka cluster with authorization using ACLs
          * `standard-kafka-acls`: _Standard_ Kafka cluster with authorization using ACLs
          * `standard-kafka-rbac`: _Standard_ Kafka cluster with authorization using RBAC
          * `dedicated-public-kafka-acls`: _Dedicated_ Kafka cluster that is accessible over the public internet with authorization using ACLs
          * `dedicated-public-kafka-rbac`: _Dedicated_ Kafka cluster that is accessible over the public internet with authorization using RBAC
          * `dedicated-privatelink-aws-kafka-acls`: _Dedicated_ Kafka cluster on AWS that is accessible via PrivateLink connections with authorization using ACLs
          * `dedicated-privatelink-aws-kafka-rbac`: _Dedicated_ Kafka cluster on AWS that is accessible via PrivateLink connections with authorization using RBAC
          * `dedicated-privatelink-azure-kafka-rbac`: _Dedicated_ Kafka cluster on Azure that is accessible via PrivateLink connections with authorization using RBAC
          * `dedicated-privatelink-azure-kafka-acls`: _Dedicated_ Kafka cluster on Azure that is accessible via PrivateLink connections with authorization using ACLs
          * `dedicated-private-service-connect-gcp-kafka-acls`: _Dedicated_ Kafka cluster on GCP that is accessible via Private Service Connect connections with authorization using ACLs
          * `dedicated-private-service-connect-gcp-kafka-rbac`: _Dedicated_ Kafka cluster on GCP that is accessible via Private Service Connect connections with authorization using RBAC
          * `dedicated-vnet-peering-azure-kafka-acls`: _Dedicated_ Kafka cluster on Azure that is accessible via VPC Peering connections with authorization using ACLs
          * `dedicated-vnet-peering-azure-kafka-rbac`: _Dedicated_ Kafka cluster on Azure that is accessible via VPC Peering connections with authorization using RBAC
          * `dedicated-vpc-peering-aws-kafka-acls`: _Dedicated_ Kafka cluster on AWS that is accessible via VPC Peering connections with authorization using ACLs
          * `dedicated-vpc-peering-aws-kafka-rbac`: _Dedicated_ Kafka cluster on AWS that is accessible via VPC Peering connections with authorization using RBAC
          * `dedicated-vpc-peering-gcp-kafka-acls`: _Dedicated_ Kafka cluster on GCP that is accessible via VPC Peering connections with authorization using ACLs
          * `dedicated-vpc-peering-gcp-kafka-rbac`: _Dedicated_ Kafka cluster on GCP that is accessible via VPC Peering connections with authorization using RBAC
          * `dedicated-transit-gateway-attachment-aws-kafka-acls`: _Dedicated_ Kafka cluster on AWS that is accessible via Transit Gateway Endpoint with authorization using ACLs
          * `dedicated-transit-gateway-attachment-aws-kafka-rbac`: _Dedicated_ Kafka cluster on AWS that is accessible via Transit Gateway Endpoint with authorization using RBAC
          * `enterprise-privatelinkattachment-aws-kafka-acls`: _Enterprise_ Kafka cluster on AWS that is accessible via PrivateLink connections with authorization using ACLs

        ## Import

        You can import a Cluster API Key by using the Environment ID and Cluster API Key ID in the format `<Environment ID>/<Cluster API Key ID>`, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        $ export API_KEY_SECRET="<api_key_secret>"

        Option #1: Cluster API Key

        ```sh
        $ pulumi import confluentcloud:index/apiKey:ApiKey example_kafka_api_key "env-abc123/UTT6WDRXX7FHD2GV"
        ```

        You can import a Cloud API Key by using Cloud API Key ID, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        $ export API_KEY_SECRET="<api_key_secret>"

        Option #2: Cloud API Key

        ```sh
        $ pulumi import confluentcloud:index/apiKey:ApiKey example_cloud_api_key "4UEXOMMWIBE5KZQG"
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param ApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 disable_wait_for_ready: Optional[pulumi.Input[bool]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 managed_resource: Optional[pulumi.Input[pulumi.InputType['ApiKeyManagedResourceArgs']]] = None,
                 owner: Optional[pulumi.Input[pulumi.InputType['ApiKeyOwnerArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiKeyArgs.__new__(ApiKeyArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["disable_wait_for_ready"] = disable_wait_for_ready
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["managed_resource"] = managed_resource
            if owner is None and not opts.urn:
                raise TypeError("Missing required property 'owner'")
            __props__.__dict__["owner"] = owner
            __props__.__dict__["secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ApiKey, __self__).__init__(
            'confluentcloud:index/apiKey:ApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            disable_wait_for_ready: Optional[pulumi.Input[bool]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            managed_resource: Optional[pulumi.Input[pulumi.InputType['ApiKeyManagedResourceArgs']]] = None,
            owner: Optional[pulumi.Input[pulumi.InputType['ApiKeyOwnerArgs']]] = None,
            secret: Optional[pulumi.Input[str]] = None) -> 'ApiKey':
        """
        Get an existing ApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A free-form description of the API Account.
        :param pulumi.Input[bool] disable_wait_for_ready: An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        :param pulumi.Input[str] display_name: A human-readable name for the API Key.
        :param pulumi.Input[pulumi.InputType['ApiKeyManagedResourceArgs']] managed_resource: The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        :param pulumi.Input[pulumi.InputType['ApiKeyOwnerArgs']] owner: The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        :param pulumi.Input[str] secret: (Required String, Sensitive) The secret of the API Key.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiKeyState.__new__(_ApiKeyState)

        __props__.__dict__["description"] = description
        __props__.__dict__["disable_wait_for_ready"] = disable_wait_for_ready
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["managed_resource"] = managed_resource
        __props__.__dict__["owner"] = owner
        __props__.__dict__["secret"] = secret
        return ApiKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A free-form description of the API Account.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="disableWaitForReady")
    def disable_wait_for_ready(self) -> pulumi.Output[Optional[bool]]:
        """
        An optional flag to disable wait-for-readiness on create. Its primary use case is for Cluster API Keys for private networking options when readiness check fails. Must be unset when importing. Defaults to `false`.
        """
        return pulumi.get(self, "disable_wait_for_ready")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        A human-readable name for the API Key.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="managedResource")
    def managed_resource(self) -> pulumi.Output[Optional['outputs.ApiKeyManagedResource']]:
        """
        The resource associated with this object. The only resource that is supported is 'cmk.v2.Cluster', 'srcm.v2.Cluster'.
        """
        return pulumi.get(self, "managed_resource")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output['outputs.ApiKeyOwner']:
        """
        The owner to which the API Key belongs. The owner can be one of 'iam.v2.User', 'iam.v2.ServiceAccount'.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[str]:
        """
        (Required String, Sensitive) The secret of the API Key.
        """
        return pulumi.get(self, "secret")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetIdentityProviderResult',
    'AwaitableGetIdentityProviderResult',
    'get_identity_provider',
    'get_identity_provider_output',
]

@pulumi.output_type
class GetIdentityProviderResult:
    """
    A collection of values returned by getIdentityProvider.
    """
    def __init__(__self__, description=None, display_name=None, id=None, issuer=None, jwks_uri=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if issuer and not isinstance(issuer, str):
            raise TypeError("Expected argument 'issuer' to be a str")
        pulumi.set(__self__, "issuer", issuer)
        if jwks_uri and not isinstance(jwks_uri, str):
            raise TypeError("Expected argument 'jwks_uri' to be a str")
        pulumi.set(__self__, "jwks_uri", jwks_uri)

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        (Required String) A description for the Identity Provider.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        (Required String) A human-readable name for the Identity Provider.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the Identity Provider, for example, `op-abc123`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def issuer(self) -> str:
        """
        (Required String) A publicly reachable issuer URI for the Identity Provider. The unique issuer URI string represents the entity for issuing tokens.
        """
        return pulumi.get(self, "issuer")

    @property
    @pulumi.getter(name="jwksUri")
    def jwks_uri(self) -> str:
        """
        (Required String) A publicly reachable JSON Web Key Set (JWKS) URI for the Identity Provider. A JSON Web Key Set (JWKS) provides a set of keys containing the public keys used to verify any JSON Web Token (JWT) issued by your OAuth 2.0 identity provider.
        """
        return pulumi.get(self, "jwks_uri")


class AwaitableGetIdentityProviderResult(GetIdentityProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentityProviderResult(
            description=self.description,
            display_name=self.display_name,
            id=self.id,
            issuer=self.issuer,
            jwks_uri=self.jwks_uri)


def get_identity_provider(display_name: Optional[str] = None,
                          id: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentityProviderResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `IdentityProvider` describes an Identity Provider data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example_using_id = confluentcloud.get_identity_provider(id="op-abc123")
    pulumi.export("exampleUsingId", example_using_id)
    example_using_name = confluentcloud.get_identity_provider(display_name="My OIDC Provider: Azure AD")
    pulumi.export("exampleUsingName", example_using_name)
    ```


    :param str display_name: A human-readable name for the Identity Provider.
           
           > **Note:** Exactly one from the `id` and `display_name` attributes must be specified.
    :param str id: The ID of the Identity Provider, for example, `op-abc123`.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getIdentityProvider:getIdentityProvider', __args__, opts=opts, typ=GetIdentityProviderResult).value

    return AwaitableGetIdentityProviderResult(
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        issuer=pulumi.get(__ret__, 'issuer'),
        jwks_uri=pulumi.get(__ret__, 'jwks_uri'))


@_utilities.lift_output_func(get_identity_provider)
def get_identity_provider_output(display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                 id: Optional[pulumi.Input[Optional[str]]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIdentityProviderResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `IdentityProvider` describes an Identity Provider data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example_using_id = confluentcloud.get_identity_provider(id="op-abc123")
    pulumi.export("exampleUsingId", example_using_id)
    example_using_name = confluentcloud.get_identity_provider(display_name="My OIDC Provider: Azure AD")
    pulumi.export("exampleUsingName", example_using_name)
    ```


    :param str display_name: A human-readable name for the Identity Provider.
           
           > **Note:** Exactly one from the `id` and `display_name` attributes must be specified.
    :param str id: The ID of the Identity Provider, for example, `op-abc123`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetUsersResult',
    'AwaitableGetUsersResult',
    'get_users',
    'get_users_output',
]

@pulumi.output_type
class GetUsersResult:
    """
    A collection of values returned by getUsers.
    """
    def __init__(__self__, id=None, ids=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        (Required List of Strings) The list of User IDs, for example: `["u-abc123", "u-abc124"]`.
        """
        return pulumi.get(self, "ids")


class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            id=self.id,
            ids=self.ids)


def get_users(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsersResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_users` describes a data source for Users.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_users()
    pulumi.export("users", main.ids)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult).value

    return AwaitableGetUsersResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'))


@_utilities.lift_output_func(get_users)
def get_users_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUsersResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_users` describes a data source for Users.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_users()
    pulumi.export("users", main.ids)
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetFlinkRegionResult',
    'AwaitableGetFlinkRegionResult',
    'get_flink_region',
    'get_flink_region_output',
]

@pulumi.output_type
class GetFlinkRegionResult:
    """
    A collection of values returned by getFlinkRegion.
    """
    def __init__(__self__, api_version=None, cloud=None, id=None, kind=None, private_rest_endpoint=None, region=None, rest_endpoint=None):
        if api_version and not isinstance(api_version, str):
            raise TypeError("Expected argument 'api_version' to be a str")
        pulumi.set(__self__, "api_version", api_version)
        if cloud and not isinstance(cloud, str):
            raise TypeError("Expected argument 'cloud' to be a str")
        pulumi.set(__self__, "cloud", cloud)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if private_rest_endpoint and not isinstance(private_rest_endpoint, str):
            raise TypeError("Expected argument 'private_rest_endpoint' to be a str")
        pulumi.set(__self__, "private_rest_endpoint", private_rest_endpoint)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if rest_endpoint and not isinstance(rest_endpoint, str):
            raise TypeError("Expected argument 'rest_endpoint' to be a str")
        pulumi.set(__self__, "rest_endpoint", rest_endpoint)

    @property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> str:
        """
        (Required String) An API Version of the Flink region, for example, `fcpm/v2`.
        """
        return pulumi.get(self, "api_version")

    @property
    @pulumi.getter
    def cloud(self) -> str:
        return pulumi.get(self, "cloud")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        (Required String) The ID of the Flink region, for example, `aws.us-east-1`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def kind(self) -> str:
        """
        (Required String) A kind of the Flink region, for example, `Region`.
        """
        return pulumi.get(self, "kind")

    @property
    @pulumi.getter(name="privateRestEndpoint")
    def private_rest_endpoint(self) -> str:
        """
        (Required String) The private HTTP endpoint of the Flink region, for example, `https://flink.us-east-1.aws.private.confluent.cloud`.
        """
        return pulumi.get(self, "private_rest_endpoint")

    @property
    @pulumi.getter
    def region(self) -> str:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> str:
        """
        (Required String) The HTTP endpoint of the Flink region, for example, `https://flink.us-east-1.aws.confluent.cloud`.
        """
        return pulumi.get(self, "rest_endpoint")


class AwaitableGetFlinkRegionResult(GetFlinkRegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFlinkRegionResult(
            api_version=self.api_version,
            cloud=self.cloud,
            id=self.id,
            kind=self.kind,
            private_rest_endpoint=self.private_rest_endpoint,
            region=self.region,
            rest_endpoint=self.rest_endpoint)


def get_flink_region(cloud: Optional[str] = None,
                     region: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFlinkRegionResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_flink_region` describes a Flink cluster data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_flink_region(cloud="AWS",
        region="us-east-1")
    pulumi.export("example", example)
    ```


    :param str cloud: The cloud service provider that hosts the region. Accepted values are: `AWS`, `AZURE`, and `GCP`.
    :param str region: The cloud service provider region, for example, `us-east-1`.
    """
    __args__ = dict()
    __args__['cloud'] = cloud
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getFlinkRegion:getFlinkRegion', __args__, opts=opts, typ=GetFlinkRegionResult).value

    return AwaitableGetFlinkRegionResult(
        api_version=pulumi.get(__ret__, 'api_version'),
        cloud=pulumi.get(__ret__, 'cloud'),
        id=pulumi.get(__ret__, 'id'),
        kind=pulumi.get(__ret__, 'kind'),
        private_rest_endpoint=pulumi.get(__ret__, 'private_rest_endpoint'),
        region=pulumi.get(__ret__, 'region'),
        rest_endpoint=pulumi.get(__ret__, 'rest_endpoint'))


@_utilities.lift_output_func(get_flink_region)
def get_flink_region_output(cloud: Optional[pulumi.Input[str]] = None,
                            region: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFlinkRegionResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_flink_region` describes a Flink cluster data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_flink_region(cloud="AWS",
        region="us-east-1")
    pulumi.export("example", example)
    ```


    :param str cloud: The cloud service provider that hosts the region. Accepted values are: `AWS`, `AZURE`, and `GCP`.
    :param str region: The cloud service provider region, for example, `us-east-1`.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetRoleBindingResult',
    'AwaitableGetRoleBindingResult',
    'get_role_binding',
    'get_role_binding_output',
]

@pulumi.output_type
class GetRoleBindingResult:
    """
    A collection of values returned by getRoleBinding.
    """
    def __init__(__self__, crn_pattern=None, id=None, principal=None, role_name=None):
        if crn_pattern and not isinstance(crn_pattern, str):
            raise TypeError("Expected argument 'crn_pattern' to be a str")
        pulumi.set(__self__, "crn_pattern", crn_pattern)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if principal and not isinstance(principal, str):
            raise TypeError("Expected argument 'principal' to be a str")
        pulumi.set(__self__, "principal", principal)
        if role_name and not isinstance(role_name, str):
            raise TypeError("Expected argument 'role_name' to be a str")
        pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter(name="crnPattern")
    def crn_pattern(self) -> str:
        """
        (Required String) A [Confluent Resource Name(CRN)](https://docs.confluent.io/cloud/current/api.html#section/Identifiers-and-URLs/Confluent-Resource-Names-(CRNs)) that specifies the scope and resource patterns necessary for the role to bind.
        """
        return pulumi.get(self, "crn_pattern")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def principal(self) -> str:
        """
        (Required String) A principal User to bind the role to, for example, "User:u-111aaa" for binding to a user "u-111aaa", or "User:sa-111aaa" for binding to a service account "sa-111aaa".
        """
        return pulumi.get(self, "principal")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> str:
        """
        (Required String) A name of the role to bind to the principal. See [Confluent Cloud RBAC Roles](https://docs.confluent.io/cloud/current/access-management/access-control/cloud-rbac.html#ccloud-rbac-roles) for a full list of supported role names.
        """
        return pulumi.get(self, "role_name")


class AwaitableGetRoleBindingResult(GetRoleBindingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoleBindingResult(
            crn_pattern=self.crn_pattern,
            id=self.id,
            principal=self.principal,
            role_name=self.role_name)


def get_role_binding(id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRoleBindingResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `RoleBinding` describes a Role Binding.

    > **Note:** For more information on the Role Bindings, see [Predefined RBAC roles in Confluent Cloud](https://docs.confluent.io/cloud/current/access-management/access-control/rbac/predefined-rbac-roles.html).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_role_binding(id="rb-abc123")
    pulumi.export("example", example)
    ```


    :param str id: The ID of the Role Binding (for example, `rb-abc123`).
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getRoleBinding:getRoleBinding', __args__, opts=opts, typ=GetRoleBindingResult).value

    return AwaitableGetRoleBindingResult(
        crn_pattern=pulumi.get(__ret__, 'crn_pattern'),
        id=pulumi.get(__ret__, 'id'),
        principal=pulumi.get(__ret__, 'principal'),
        role_name=pulumi.get(__ret__, 'role_name'))


@_utilities.lift_output_func(get_role_binding)
def get_role_binding_output(id: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRoleBindingResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `RoleBinding` describes a Role Binding.

    > **Note:** For more information on the Role Bindings, see [Predefined RBAC roles in Confluent Cloud](https://docs.confluent.io/cloud/current/access-management/access-control/rbac/predefined-rbac-roles.html).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_role_binding(id="rb-abc123")
    pulumi.export("example", example)
    ```


    :param str id: The ID of the Role Binding (for example, `rb-abc123`).
    """
    ...
